Features
========

**General**

* Pure Python implementation
* Reliable fully implicit solver
* Flexible precision

**Electric**

* Cell centered finite-volume
* Scharfetter-Gummel discretization
* Conservation of charge guaranteed in a converged solution
* Arbitrary number of layers
* Ramo-Shockley calculation of terminal current
* Arbitrary temperature
* Support for multidimensional discretizations
* Arbitrary number of transported species

**Optical**

* Transfer matrix approach
* Arbitrary number of layers

**Analysis**

* DC
* Transient
* AC small signal
* Sensitivity analysis

**Models**

* Gaussian DOS
* Extended Gaussian Disorder Model
* Generalized Einstein's relation
* Transient traps
* Shockley-Read-Hall recombination
* Langevin recombination
* Image-force barrier lowering
* Doping (also position dependent)
* Generation (also position dependent)
* Onsager-Braun model of exciton dissociation
* User supplied mobility model
* User supplied DOS

**Outputs**

* Current-voltage
* Current-voltage-light
* SCL
* Transient SCL
* Capacitance-voltage
* Impedance spectroscopy
* Efficiency (photovoltaic)
* Fill factor (photovoltaic)
* Dark current (photodetector)
* Responsivity (photodetector)
* Light output (light emitting diodes)
